from setuptools import setup

setup(name='proba-dist',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['distributions'],
      author = 'Emmanuel Siaw Darko' ,
      author_email = 'immanuelsiawdarko@gmail.com' ,
      zip_safe=False)
